@@ -2,12 +2,14 @@ import asyncio
 import random
 import time
 import unittest
+from unittest.mock import patch
 
 import pytest
 
 import gradio as gr
 from gradio.routes import PredictBody
 from gradio.test_data.blocks_configs import XRAY_CONFIG
+from gradio.utils import assert_configs_are_equivalent_besides_ids
 
 pytest_plugins = ("pytest_asyncio",)
 
@@ -15,6 +17,30 @@ pytest_plugins = ("pytest_asyncio",)
 class TestBlocks(unittest.TestCase):
     maxDiff = None
 
+    def test_set_share(self):
+        with gr.Blocks() as demo:
+            # self.share is False when instantiating the class
+            self.assertFalse(demo.share)
+            # default is False, if share is None
+            demo.share = None
+            self.assertFalse(demo.share)
+            # if set to True, it doesn't change
+            demo.share = True
+            self.assertTrue(demo.share)
+
+    @patch("gradio.utils.colab_check")
+    def test_set_share_in_colab(self, mock_colab_check):
+        mock_colab_check.return_value = True
+        with gr.Blocks() as demo:
+            # self.share is False when instantiating the class
+            self.assertFalse(demo.share)
+            # default is True, if share is None and colab_check is true
+            demo.share = None
+            self.assertTrue(demo.share)
+            # if set to True, it doesn't change
+            demo.share = True
+            self.assertTrue(demo.share)
+
     def test_xray(self):
         def fake_func():
             return "Hello There"
@@ -60,7 +86,24 @@ class TestBlocks(unittest.TestCase):
 
         config = demo.get_config_file()
         config.pop("version")  # remove version key
-        self.assertDictEqual(XRAY_CONFIG, config)
+        self.assertTrue(assert_configs_are_equivalent_besides_ids(XRAY_CONFIG, config))
+
+    def test_load_from_config(self):
+        def update(name):
+            return f"Welcome to Gradio, {name}!"
+
+        with gr.Blocks() as demo1:
+            inp = gr.Textbox(placeholder="What is your name?")
+            out = gr.Textbox()
+
+            inp.submit(fn=update, inputs=inp, outputs=out, api_name="greet")
+
+            gr.Image().style(height=54, width=240)
+
+        config1 = demo1.get_config_file()
+        demo2 = gr.Blocks.from_config(config1, [update])
+        config2 = demo2.get_config_file()
+        self.assertTrue(assert_configs_are_equivalent_besides_ids(config1, config2))
 
     @pytest.mark.asyncio
     async def test_async_function(self):
