@@ -4,6 +4,7 @@ import os
 import unittest
 
 from gradio import queueing
+from gradio.routes import QueuePushBody
 
 os.environ["GRADIO_ANALYTICS_ENABLED"] = "False"
 
@@ -30,21 +31,33 @@ class TestQueuingActions(unittest.TestCase):
         queueing.close()
 
     def test_push_pop_status(self):
-        hash1, position = queueing.push({"data": "test1"}, "predict")
+        request = QueuePushBody(
+            data="test1", action="predict", fn_index=0, session_hash="-"
+        )
+        hash1, position = queueing.push(request)
         self.assertEquals(position, 0)
-        hash2, position = queueing.push({"data": "test2"}, "predict")
+        request = QueuePushBody(
+            data="test2", action="predict", fn_index=0, session_hash="-"
+        )
+        hash2, position = queueing.push(request)
         self.assertEquals(position, 1)
         status, position = queueing.get_status(hash2)
         self.assertEquals(status, "QUEUED")
         self.assertEquals(position, 1)
         _, hash_popped, input_data, action = queueing.pop()
         self.assertEquals(hash_popped, hash1)
-        self.assertEquals(input_data, {"data": "test1"})
+        self.assertEquals(
+            input_data,
+            {"action": "predict", "data": "test1", "fn_index": 0, "session_hash": "-"},
+        )
         self.assertEquals(action, "predict")
 
     def test_jobs(self):
-        hash1, _ = queueing.push({"data": "test1"}, "predict")
-        hash2, position = queueing.push({"data": "test1"}, "predict")
+        request = QueuePushBody(
+            data="test1", action="predict", fn_index=0, session_hash="-"
+        )
+        hash1, _ = queueing.push(request)
+        hash2, position = queueing.push(request)
         self.assertEquals(position, 1)
 
         queueing.start_job(hash1)
